# Terminut.
<img src="https://img.shields.io/pypi/v/terminut?style=for-the-badge&logo=python">
<img alt="followers" src="https://img.shields.io/github/followers/imvast?color=f429ff&style=for-the-badge&logo=github&label=Follow"/>

```less
            > Custom Console Going To Be Used For My Projects
                And Available To Anyone Else Who Wants To Use <
```

---

### Installation
```yaml
! package not available yet for non-personal use !
```

### Usage
```py
from terminut.console import printf as print, inputf as input, init

init(
    gradient=True,
    showTimestamp=True,
    madeBy="vast#1337"
)

print("Cool Stuff")
```

---

## * [vast#1337](https://discord.com/users/852976920148967485) | [imvast@github](https://github.com/imvast) | [vast.gay](https://vast.gay) *